aboutsummaryrefslogtreecommitdiff
path: root/src/zenserver/compute/computeserver.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/zenserver/compute/computeserver.cpp')
-rw-r--r--src/zenserver/compute/computeserver.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/zenserver/compute/computeserver.cpp b/src/zenserver/compute/computeserver.cpp
index 173f56386..0f9ef0287 100644
--- a/src/zenserver/compute/computeserver.cpp
+++ b/src/zenserver/compute/computeserver.cpp
@@ -82,7 +82,7 @@ ZenComputeServer::Initialize(const ZenComputeServerConfig& ServerConfig, ZenServ
ZEN_TRACE_CPU("ZenComputeServer::Initialize");
ZEN_MEMSCOPE(GetZenserverTag());
- ZEN_INFO(ZEN_APP_NAME " initializing in HUB server mode");
+ ZEN_INFO(ZEN_APP_NAME " initializing in COMPUTE server mode");
const int EffectiveBasePort = ZenServerBase::Initialize(ServerConfig, ServerEntry);
if (EffectiveBasePort < 0)
@@ -91,7 +91,7 @@ ZenComputeServer::Initialize(const ZenComputeServerConfig& ServerConfig, ZenServ
}
// This is a workaround to make sure we can have automated tests. Without
// this the ranges for different child zen hub processes could overlap with
// the main test range.
ZenServerEnvironment::SetBaseChildId(1000);
@@ -109,7 +109,7 @@ ZenComputeServer::Initialize(const ZenComputeServerConfig& ServerConfig, ZenServ
void
ZenComputeServer::Cleanup()
{
- ZEN_TRACE_CPU("ZenStorageServer::Cleanup");
+ ZEN_TRACE_CPU("ZenComputeServer::Cleanup");
ZEN_INFO(ZEN_APP_NAME " cleaning up");
try
{
@@ -91,7 +91,7 @@ ZenComputeServer::Initialize(const ZenComputeServerConfig& ServerConfig, ZenServ
}
// This is a workaround to make sure we can have automated tests. Without
- // this the ranges for different child zen hub processes could overlap with
+ // this the ranges for different child zen compute processes could overlap with
// the main test range.
ZenServerEnvironment::SetBaseChildId(1000);